@@ -44,6 +44,7 @@ static char SCCSID[] = "@(#) Module: xtmAlarmCtrl.c, Version: 1.1, Date: 95/02/1
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
+#include <ctype.h>
 #include <sys/types.h>
 #include <sys/signal.h>
 #include <sys/stat.h>
@@ -781,7 +782,6 @@ static Boolean
   int                     index;
   int                     n;
   int                     pid;
-  char                    font_size[ 50 ];
   char                    **process_args;
   Display                 *display = NULL;
   Window                  window = None;
