@@ -45,6 +45,7 @@ static char SCCSID[] = "@(#) Module: xtmArchive.c, Version: 1.1, Date: 95/02/18
 #include <Xm/BulletinB.h>
 #include <Xm/Form.h>
 #include <Xm/List.h>
+#include <Xm/Text.h>
 
 #include "System.h"
 #include "LstLinked.h"
@@ -54,6 +55,7 @@ static char SCCSID[] = "@(#) Module: xtmArchive.c, Version: 1.1, Date: 95/02/18
 #include "msgXdiary.h"
 #include "xtmCalDb.h"
 #include "xtmDbTools.h"
+#include "xtmDbMisc.h"
 #include "xtmFormat.h"
 #include "xtmHelp.h"
 #include "xtmUpdate.h"
