@@ -38,6 +38,7 @@ static char SCCSID[] = "@(#) Module: xtmBaseCal.c, Version: 1.1, Date: 95/02/18
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <assert.h>
 
 #include <X11/Intrinsic.h>
 
@@ -54,6 +55,8 @@ static char SCCSID[] = "@(#) Module: xtmBaseCal.c, Version: 1.1, Date: 95/02/18
 #include "xtmGlobal.h"
 #include "xtmDbTools.h"
 #include "xtmIcons.h"
+#include "xtmFormat.h"
+#include "xtmHoliday.h"
 #include "xitError.h"
 #include "xitTools.h"
 #include "XmUbMonthD.h"
@@ -474,12 +477,11 @@ static Widget
   char                    buffer[ 20 ];
   Arg                     args[ 20 ];
   Cardinal                n;
-  Widget                  calendarW;
+  Widget                  calendarW = 0;
   Widget                  dataLocalW[ 3 ];
   Widget                  messageBu;
   Widget                  month_tab[ 12 ];
   Widget                  notebookW[ 2 ];
-  Widget                  plainW[ 2 ];
   Widget                  tempW;
   Widget                  year_tab[ NO_OF_YEAR_TABS ];
   XmString                xstr;
@@ -699,7 +701,7 @@ static Widget
     cal_ref -> workAreaW = calFo;
 
   } /* if */
-
+  assert( calendarW != 0 );
 
   /* Create date button. */
   todayDateBu = xitCreatePushButton(  calFo, &button_def[ 0 ] );
