@@ -84,6 +84,8 @@ static char SCCSID[] = "@(#) Module: xtmCalendar.c, Version: 1.1, Date: 95/02/18
 #include "xtmShowToDo.h"
 #include "xtmTools.h"
 #include "xtmUpdate.h"
+#include "xtmHoliday.h"
+#include "xtmSchedMain.h"
 #include "xitError.h"
 #include "xitTools.h"
 
@@ -1252,7 +1254,6 @@ static void
   /* Variables. */
   int                     index;
   int                     n;
-  char                    font_size[ 50 ];
   char                    **process_args;
   XTM_GL_CUSTOM_DATA_REF  custom_data_ref;
 
