@@ -59,6 +59,7 @@ static char SCCSID[] = "@(#) Module: xtmCpMvEntry.c, Version: 1.1, Date: 95/02/1
 #include "xtmHelp.h"
 #include "xtmTools.h"
 #include "xtmUpdate.h"
+#include "xtmDbMisc.h"
 #include "xitError.h"
 #include "xitFieldSel.h"
 #include "xitTools.h"
@@ -713,7 +714,7 @@ static void
 
     if( new_entry.stand_entry.to > 0 &&
         new_entry.stand_entry.to < new_entry.stand_entry.from )
-      new_entry.stand_entry.to == 0;
+      new_entry.stand_entry.to = 0;
   }
 
 
