@@ -38,12 +38,15 @@ static char SCCSID[] = "@(#) Module: xtmDbFilter.c, Version: 1.1, Date: 95/02/18
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 
 #include <Xm/Xm.h>
 #include <Xm/RowColumn.h>
 #include <Xm/SeparatoG.h>
+#include <Xm/ToggleB.h>
+#include <Xm/Text.h>
 
 #include "System.h"
 #include "Message.h"
