@@ -38,12 +38,14 @@ static char SCCSID[] = "@(#) Module: xtmDbInclude.c, Version: 1.1, Date: 95/02/1
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 
 #include <Xm/Xm.h>
 #include <Xm/ScrolledW.h>
 #include <Xm/RowColumn.h>
+#include <Xm/ToggleB.h>
 
 #include "System.h"
 #include "Message.h"
@@ -443,7 +445,7 @@ static void
   /* Code. */
 
   mainW = XtNameToWidget( include_ref -> includeW, 
-                          "IncFdFo.IncSw.ScrolledWindowClipWindow.IncRc" );
+                          "IncFdFo.IncSw.ClipWindow.IncRc" );
 
   /* Fetch the data. */
   cal_count     = 0;
@@ -502,7 +504,7 @@ static void
   /* Code. */
 
   mainW = XtNameToWidget( include_ref -> includeW, 
-                          "IncFdFo.IncSw.ScrolledWindowClipWindow.IncRc" );
+                          "IncFdFo.IncSw.ClipWindow.IncRc" );
 
   /* Set or clear all include indicators. */
   index = 0;
@@ -569,7 +571,7 @@ static void
 
 
   /* Remove all old calendars. */
-  baseW = XtNameToWidget( mainW, "IncSw.ScrolledWindowClipWindow.IncRc" );
+  baseW = XtNameToWidget( mainW, "IncSw.ClipWindow.IncRc" );
   index = 1;
 
   do {
@@ -645,7 +647,7 @@ static void
 
 
   /* Create the list of calendars. */
-  baseW = XtNameToWidget( mainW, "IncSw.ScrolledWindowClipWindow.IncRc" );
+  baseW = XtNameToWidget( mainW, "IncSw.ClipWindow.IncRc" );
 
   for( index = 0; index < cal_count; index++ ) {
 
