@@ -36,8 +36,8 @@ static char SCCSID[] = "@(#) Module: xtmDbMisc.c, Version: 1.1, Date: 95/02/18 1
 --  Include files
 ----------------------------------------------------------------------------*/
 
-#include <malloc.h>
 #include <stdio.h>
+#include <ctype.h>
 #include <sys/types.h>
 #include <unistd.h>
 
