@@ -52,6 +52,7 @@ static char SCCSID[] = "@(#) Module: xtmEditAclUx.c, Version: 1.1, Date: 95/02/1
 #include <Xm/List.h>
 #include <Xm/RowColumn.h>
 #include <Xm/Text.h>
+#include <Xm/ToggleB.h>
 
 #include "System.h"
 #include "LstLinked.h"
@@ -1055,13 +1056,13 @@ static void
 
   /* Set the flag values. */
   tempW = XtNameToWidget( mainW, "FlagRc.FlagReadTb" );
-  XmToggleButtonSetState( tempW, False );
+  XmToggleButtonSetState( tempW, False, False );
 
   tempW = XtNameToWidget( mainW, "FlagRc.FlagWriteTb" );
-  XmToggleButtonSetState( tempW, False );
+  XmToggleButtonSetState( tempW, False, False );
 
   tempW = XtNameToWidget( mainW, "FlagRc.FlagMsgTb" );
-  XmToggleButtonSetState( tempW, False );
+  XmToggleButtonSetState( tempW, False, False );
 
 
   /* No items selected. */
