@@ -49,6 +49,7 @@ static char SCCSID[] = "@(#) Module: xtmEditAlarm.c, Version: 1.1, Date: 95/02/1
 #include <Xm/Frame.h>
 #include <Xm/RowColumn.h>
 #include <Xm/Text.h>
+#include <Xm/ToggleB.h>
 
 #include "System.h"
 #include "Message.h"
@@ -708,7 +709,7 @@ static void
     sprintf( buffer, "Alarm%dTx", index + 1 );
     tempW = XtNameToWidget( baseW, buffer );
 
-    sprintf( buffer, "" );
+    /* sprintf( buffer, "" ); */
 
     if( values_ref -> alarm_valid[ index ] ) {
 
