@@ -43,6 +43,7 @@ static char SCCSID[] = "@(#) Module: xtmEditEntry.c, Version: 1.1, Date: 95/02/1
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -1444,7 +1445,7 @@ static Boolean
                   module_name, "fetchBaseFromWindow",
                   msgGetText( MXDI_ENTRY_HAS_NO_TEXT ) );
 
-    SysFree( *entry_text );
+    /* freeing seems to be already done in exception handling */
     return( False );
   }
 
@@ -2484,7 +2485,6 @@ static void
 
   /* Variables. */
   Boolean                 ok;
-  char                    *char_ref;
   Widget                  mainW;
   Widget                  tempW;
   TIM_TIME_REF            entry_date;
