@@ -467,7 +467,7 @@ static Boolean
 
   /* Get the weeks we skip this entry. */
   baseW = XtNameToWidget( mainW, 
-                          "SkipSw.ScrolledWindowClipWindow.SkipWeekRc" );
+                          "SkipSw.ClipWindow.SkipWeekRc" );
 
   for( index = 1; index <= 53; index++ ) {
 
@@ -525,7 +525,7 @@ static void
 
   /* Set the weeks we skip this entry. */
   baseW = XtNameToWidget( mainW, 
-                          "SkipSw.ScrolledWindowClipWindow.SkipWeekRc" );
+                          "SkipSw.ClipWindow.SkipWeekRc" );
 
   for( index = 1; index <= 53; index++ ) {
 
@@ -690,7 +690,7 @@ static void
 
   mainW = XtNameToWidget( skip_ref -> skipW, "SkipFdFo" );
   baseW = XtNameToWidget( mainW, 
-                          "SkipSw.ScrolledWindowClipWindow.SkipWeekRc" );
+                          "SkipSw.ClipWindow.SkipWeekRc" );
 
   /* Reset all skip buttons. */
   for( index = 0; index < 53; index++ ) {
@@ -734,7 +734,7 @@ static void
 
   mainW = XtNameToWidget( skip_ref -> skipW, "SkipFdFo" );
   baseW = XtNameToWidget( mainW, 
-                          "SkipSw.ScrolledWindowClipWindow.SkipWeekRc" );
+                          "SkipSw.ClipWindow.SkipWeekRc" );
 
   week_no = TimIndexOfIsoWeek( skip_ref -> default_date );
 
