@@ -50,6 +50,7 @@ static char SCCSID[] = "@(#) Module: xtmEditStand.c, Version: 1.1, Date: 95/02/1
 #include <Xm/RowColumn.h>
 #include <Xm/SeparatoG.h>
 #include <Xm/Text.h>
+#include <Xm/ToggleB.h>
 
 #include "System.h"
 #include "Message.h"
@@ -190,9 +191,10 @@ static void
         STAND_REC_REF  stand_ref,
         XtPointer      call_data );
 
-static void
-  rangeActionCB( char  *range_str,
+/* static void
+  rangeActionCB( char  *range_str, 
                  void  *user_data );
+*/
 
 static void
   setDefaultStandValues( STAND_REC_REF  stand_ref );
@@ -997,14 +999,12 @@ static void
 {
 
   /* Variables. */
-  Boolean               set_value;
   Boolean               valid;
   int                   index;
   char                  buffer[ 80 ];
   Widget                baseW;
   Widget                mainW;
   Widget                tempW;
-  XTM_GL_BASE_DATA_REF  appl_data_ref;
 
 
   /* Code. */
