@@ -38,6 +38,7 @@ static char SCCSID[] = "@(#) Module: xtmMsgSend.c, Version: 1.1, Date: 95/02/18
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -50,6 +51,8 @@ static char SCCSID[] = "@(#) Module: xtmMsgSend.c, Version: 1.1, Date: 95/02/18
 #include <Xm/RowColumn.h>
 #include <Xm/SeparatoG.h>
 #include <Xm/Text.h>
+#include <Xm/ToggleB.h>
+
 
 #include "System.h"
 #include "LstLinked.h"
@@ -73,6 +76,7 @@ static char SCCSID[] = "@(#) Module: xtmMsgSend.c, Version: 1.1, Date: 95/02/18
 #include "xitTools.h"
 #include "XmUbTimeB.h"
 #include "xtmMsgSend.h"
+#include "xtmDbMisc.h"
 
 
 /*----------------------------------------------------------------------------
@@ -1427,7 +1431,7 @@ static void
 
 
   /* Duration of the appointment. */
-  sprintf( buffer, "" );
+  /* sprintf( buffer, "" ); */
 
   switch( entry_record.entry.entry_type ) {
     case XTM_DB_DAY_ENTRY:
