@@ -38,11 +38,13 @@ static char SCCSID[] = "@(#) Module: xtmPickDiary.c, Version: 1.1, Date: 95/02/1
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 
 #include <Xm/Xm.h>
 #include <Xm/List.h>
+#include <Xm/Text.h>
 #include <Xm/RowColumn.h>
 
 #include "System.h"
@@ -55,7 +57,7 @@ static char SCCSID[] = "@(#) Module: xtmPickDiary.c, Version: 1.1, Date: 95/02/1
 #include "xitInfo.h"
 #include "xitTools.h"
 #include "xtmPickDiary.h"
-
+#include "DirList.h"
 
 /*----------------------------------------------------------------------------
 --  Macro definitions
