@@ -38,6 +38,7 @@ static char SCCSID[] = "@(#) Module: xtmPrEntries.c, Version: 1.1, Date: 95/02/1
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
+#include <ctype.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
@@ -1219,7 +1220,6 @@ static void
   char          buffer[ 100 ];
   char          flags[ 20 ];
   char          *char_ref;
-  TIM_TIME_REF  entry_time;
 
 
   /* Code. */
@@ -1371,7 +1371,6 @@ static void
   LST_STATUS            lst_status;
   TIM_TIME_REF          current_date;
   TIM_TIME_REF          entry_date;
-  TIM_TIME_REF          entry_time;
   TIM_TIME_REF          from_date;
   TIM_TIME_REF          to_date;
   XTM_DB_ALL_ENTRY_DEF  entry_record;
