@@ -329,7 +329,7 @@ static Widget
   Widget    dataLocalW[ 19 ];
 
   static XIT_PUSH_STRUCT button_def[] = {
-    "PwdChangePb", "", "", True, NULL,
+    { "PwdChangePb", "", "", True, NULL }
   };
 
   static XIT_TEXT_STRUCT text_buffer[] = {
