@@ -47,6 +47,7 @@ static char SCCSID[] = "@(#) Module: xtmSchedAct.c, Version: 1.1, Date: 95/02/18
 #include <Xm/Xm.h>
 #include <Xm/PushB.h>
 #include <Xm/RowColumn.h>
+#include <Xm/ToggleB.h>
 
 #include "LstLinked.h"
 #include "Message.h"
@@ -68,6 +69,11 @@ static char SCCSID[] = "@(#) Module: xtmSchedAct.c, Version: 1.1, Date: 95/02/18
 #include "xtmUpdate.h"
 #include "xitError.h"
 #include "xitTools.h"
+#include "xtmEntryClip.h"
+#include "xtmDelEntry.h"
+#include "xtmDuplEntry.h"
+#include "xtmArchive.h"
+
 
 #include "xtmSchedPriv.h"
 #include "xtmSchedAct.h"
@@ -179,7 +185,7 @@ void
 
     /* React only on events on the background. */
     bgW = XtNameToWidget( mainW, 
-      "SchedPa.Pane2Fo.EntrySw.ScrolledWindowClipWindow.EntryBb" );
+      "SchedPa.Pane2Fo.EntrySw.ClipWindow.EntryBb" );
 
     if( bgW != widget )
       return;
@@ -1095,7 +1101,7 @@ void
   XTM_CD_CAL_INFO         db_info;
 
   static XIT_PUSH_STRUCT button_def[] = {
-    "AnimatePb", " ", "", False, NULL,
+    { "AnimatePb", " ", "", False, NULL }
   };
 
 
