@@ -50,6 +50,7 @@ static char SCCSID[] = "@(#) Module: xtmSchedWin.c, Version: 1.1, Date: 95/02/18
 #include <Xm/ScrolledW.h>
 #include <Xm/Separator.h>
 #include <Xm/Text.h>
+#include <Xm/ScrollBar.h>
 
 #include "xitRwPixB.h"
 
@@ -70,7 +71,7 @@ static char SCCSID[] = "@(#) Module: xtmSchedWin.c, Version: 1.1, Date: 95/02/18
 #include "xitError.h"
 #include "xitTools.h"
 #include "XmUbTimeB.h"
-
+#include "xtmHoliday.h"
 #include "xtmSchedPriv.h"
 #include "xtmSchedWin.h"
 
@@ -682,7 +683,6 @@ void
   /* Variables. */
   Boolean               ok;
   char                  buffer[ 50 ];
-  char                  *char_ref;
   Widget                mainW;
   Widget                tempW;
   TIM_TIME_REF          start_date;
@@ -964,7 +964,6 @@ static void
   /* Variables. */
   Boolean                 update_labels = True;
   int                     day_index;
-  int                     year = 0;
   char                    buffer[ 50 ];
   char                    buffer1[ 50 ];
   char                    day_buffer[ 50 ];
@@ -981,10 +980,6 @@ static void
   XTM_GL_BASE_DATA_REF    appl_data_ref;
   XTM_GL_CUSTOM_DATA_REF  custom_data_ref;
 
-  static XIT_PUSH_STRUCT button_data[] = {
-    "", " ", "", True, NULL
-  };
-
 
   /* Code. */
 
@@ -1006,7 +1001,7 @@ static void
   /* Widgets we will need. */
   dayDispBbW = XtNameToWidget( 
                  mainW, 
-                 "DayDispSw.ScrolledWindowClipWindow.DayDispBb" );
+                 "DayDispSw.ClipWindow.DayDispBb" );
 
   now = TimLocalTime( TimMakeTimeNow() );
 
@@ -1195,7 +1190,7 @@ static void
   XTM_CD_CAL_INFO         db_info;
 
   static XIT_PUSH_STRUCT button_data[] = {
-    " ", " ", " ", True, NULL
+    { " ", " ", " ", True, NULL }
   };
 
 
@@ -1210,11 +1205,11 @@ static void
 
   noteBbW = XtNameToWidget( 
               mainW, 
-              "SchedPa.Pane1Fo.NoteSw.ScrolledWindowClipWindow.NoteBb" );
+              "SchedPa.Pane1Fo.NoteSw.ClipWindow.NoteBb" );
 
   entryBbW = XtNameToWidget( 
                mainW, 
-               "SchedPa.Pane2Fo.EntrySw.ScrolledWindowClipWindow.EntryBb" );
+               "SchedPa.Pane2Fo.EntrySw.ClipWindow.EntryBb" );
 
   /* Make sure the BB's are big enough (correct size will be set later). */
   n = 0;
@@ -1934,11 +1929,11 @@ static void
   /* Widgets we will need. */
   noteBbW = XtNameToWidget( 
               mainW, 
-              "SchedPa.Pane1Fo.NoteSw.ScrolledWindowClipWindow.NoteBb" );
+              "SchedPa.Pane1Fo.NoteSw.ClipWindow.NoteBb" );
 
   entryBbW = XtNameToWidget( 
                mainW, 
-               "SchedPa.Pane2Fo.EntrySw.ScrolledWindowClipWindow.EntryBb" );
+               "SchedPa.Pane2Fo.EntrySw.ClipWindow.EntryBb" );
 
 
 
@@ -2190,7 +2185,7 @@ static void
   timeDispW = XtNameToWidget( mainW, 
                               "SchedPa.Pane2Fo.TimeDispSw" );
   timeLaW = XtNameToWidget( timeDispW, 
-                            "ScrolledWindowClipWindow.TimeDispBb.TimeDispLa" );
+                            "ClipWindow.TimeDispBb.TimeDispLa" );
 
 
   /* Create a label containing the times. */
