@@ -393,7 +393,6 @@ void
 {
 
   /* Variables. */
-  char                    buffer[ 256 ];
   Widget                  mainW;
   Widget                  tempW;
   SHOW_REC_REF            show_ref;
@@ -1067,7 +1066,7 @@ static void
 
 
   /* Set the text. */
-  tempW = XtNameToWidget( mainW, "TextSw.ScrolledWindowClipWindow.TextLa" );
+  tempW = XtNameToWidget( mainW, "TextSw.ClipWindow.TextLa" );
 
   xitStringSetLabel( tempW, text_ref );
 
