@@ -55,6 +55,8 @@ static char SCCSID[] = "@(#) Module: TimDate.c, Version: 1.1, Date: 95/02/18 14:
 #include <string.h>
 #include <time.h>
 #include <sys/types.h>
+#include <stdlib.h>
+#include <ctype.h>
 
 #include "System.h"
 #include "TimDate.h"
@@ -1943,8 +1945,23 @@ static TIM_STATUS_TYPE
   /* Code. */
 
   /* The easy check. */
+#ifdef NO_RXTN
   if( year < 1900 )
     year = year + 1900;
+#else
+  if ( year < 1970 ) {
+    if ( year >= 70 && year < 100 )
+      year += 1900;
+    else
+      if ( year <= 30 )
+	year += 2000;
+      else
+	return TIM_ERROR;
+    }
+  else
+    if ( year > 2030 )
+      return TIM_ERROR;
+#endif      
 
   if( year   < 1970 || year   > 2100 ||
       month  < 1    || month  > 12 ||
