@@ -38,6 +38,8 @@ static char SCCSID[] = "@(#) Module: xtmAclUnix.c, Version: 1.1, Date: 95/02/18
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
+#include <unistd.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -67,7 +69,7 @@ static char SCCSID[] = "@(#) Module: xtmAclUnix.c, Version: 1.1, Date: 95/02/18
 #include "xitInfo.h"
 #include "xitStickyMsg.h"
 #include "xitTools.h"
-
+#include "xtmTools.h"
 
 /*----------------------------------------------------------------------------
 --  Macro definitions
