@@ -54,6 +54,7 @@ static char SCCSID[] = "@(#) Module: xtmAlarmProc.c, Version: 1.1, Date: 95/02/1
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
+#include <ctype.h>
 #include <sys/signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -86,7 +87,10 @@ static char SCCSID[] = "@(#) Module: xtmAlarmProc.c, Version: 1.1, Date: 95/02/1
 #include "xitError.h"
 #include "xitStickyMsg.h"
 #include "xitTools.h"
-
+#include "xtmTools.h"
+#include "xtmHoliday.h"
+#include "xtmFormat.h"
+#include "xtmDbTools.h"
 
 /*----------------------------------------------------------------------------
 --  Macro definitions
@@ -284,23 +288,21 @@ static  int ani_pixmap_seq[] = {
 
 /* Program options. */
 static XrmOptionDescRec options[] = {
-  { "-alarmTags",   "*.FilterAlarmTags", XrmoptionSepArg,  NULL },
-  { "-alarmtags",   "*.FilterAlarmTags", XrmoptionSepArg,  NULL },
-  { "-cmdPipeId",   "*.CmdPipeId",       XrmoptionSepArg,  NULL },
-  { "-dbName",      "*.DefaultDbAlarms", XrmoptionSepArg,  NULL },
-  { "-dbname",      "*.DefaultDbAlarms", XrmoptionSepArg,  NULL },
-  { "-calendars",   "*.DefaultDbAlarms", XrmoptionSepArg,  NULL },
+  { "-alarmTags",   "*.FilterAlarmTags", XrmoptionSepArg, NULL },
+  { "-alarmtags",   "*.FilterAlarmTags", XrmoptionSepArg, NULL },
+  { "-cmdPipeId",   "*.CmdPipeId",       XrmoptionSepArg, NULL },
+  { "-dbName",      "*.DefaultDbAlarms", XrmoptionSepArg, NULL },
+  { "-dbname",      "*.DefaultDbAlarms", XrmoptionSepArg, NULL },
+  { "-calendars",   "*.DefaultDbAlarms", XrmoptionSepArg, NULL },
   { "-debug",       "*.debug",           XrmoptionNoArg,  "True" },
-  { "-geometry",    "AlarmTl.geometry",  XrmoptionSepArg,  NULL },
-  { "-h",           "*.StartupHelp",     XrmoptionNoArg,   "True" },
-  { "-help",        "*.StartupHelp",     XrmoptionNoArg,   "True" },
-  { "-iconic",      "AlarmTl.iconic",    XrmoptionNoArg,   "True" },
-  { "-lan",         "*.msgLanguage",     XrmoptionSepArg,  NULL },
-  { "-language",    "*.msgLanguage",     XrmoptionSepArg,  NULL },
+  { "-h",           "*.StartupHelp",     XrmoptionNoArg,  "True" },
+  { "-help",        "*.StartupHelp",     XrmoptionNoArg,  "True" },
+  { "-lan",         "*.msgLanguage",     XrmoptionSepArg, NULL },
+  { "-language",    "*.msgLanguage",     XrmoptionSepArg, NULL },
   { "-noFileLock",  "*.useFileLock",     XrmoptionNoArg,  "False" },
   { "-nofilelock",  "*.useFileLock",     XrmoptionNoArg,  "False" },
-  { "-usage",       "*.StartupHelp",     XrmoptionNoArg,   "True" },
-  { "-version",     "*.VersionHelp",     XrmoptionNoArg,   "True" },
+  { "-usage",       "*.StartupHelp",     XrmoptionNoArg,  "True" },
+  { "-version",     "*.VersionHelp",     XrmoptionNoArg,  "True" },
 };
 
 /* Application resources. */
@@ -2028,8 +2030,6 @@ static void
     return;
   }
 
-  xtmDbCloseEntryDb( &database );
-
 
   /* View the entry. */
   if( entry_text_ref != NULL )
