@@ -78,6 +78,7 @@ static char SCCSID[] = "@(#) Module: xtmCustom.c, Version: 1.1, Date: 95/02/18 1
 #include "xitParSet.h"
 #include "xitStickyMsg.h"
 #include "xitTools.h"
+#include "xtmTools.h"
 #include "xtmCustom.h"
 
 
@@ -1300,7 +1301,6 @@ static int
 
   /* Variables. */
   int      pid;
-  int      status;
   Display  *display = NULL;
   Widget   tempW;
 
@@ -1439,7 +1439,6 @@ static void
   /* Variables. */
   int                     index;
   int                     n;
-  char                    font_size[ 50 ];
   char                    **process_args;
   Display                 *display;
   XTM_GL_CUSTOM_DATA_REF  custom_data_ref;
