@@ -40,6 +40,7 @@ static char SCCSID[] = "@(#) Module: xtmDump.c, Version: 1.1, Date: 95/02/18 16:
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 
@@ -145,6 +146,7 @@ static void
 --  Functions
 ----------------------------------------------------------------------------*/
 
+int
 main( int argc, char *argv[] )
 {
 
@@ -519,7 +521,7 @@ main( int argc, char *argv[] )
 
   if( file_ref == NULL ) {
     fprintf( stderr, "%s: Cannot open file %s for write.\n" ,
-             program_name );
+             program_name, output_file );
     exit( 1 );
   }
 
