@@ -38,6 +38,8 @@ static char SCCSID[] = "@(#) Module: xtmDiary.c, Version: 1.1, Date: 95/02/18 16
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <ctype.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/signal.h>
 #include <sys/stat.h>
@@ -212,7 +214,7 @@ static void
 ----------------------------------------------------------------------------*/
 
 void 
-  main( unsigned int argc, char **argv )
+  main( int argc, char **argv )
 {
 
   /* Variables. */
