@@ -38,6 +38,7 @@ static char SCCSID[] = "@(#) Module: xtmDiaryLgt.c, Version: 1.1, Date: 95/02/18
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 #include <sys/types.h>
 #include <sys/signal.h>
 #include <sys/stat.h>
@@ -75,6 +76,7 @@ static char SCCSID[] = "@(#) Module: xtmDiaryLgt.c, Version: 1.1, Date: 95/02/18
 #include "xitStickyMsg.h"
 #include "xitTools.h"
 #include "xitInfo.h"
+#include "xtmFormat.h"
 
 
 /*----------------------------------------------------------------------------
@@ -586,9 +588,13 @@ static void
 
 
   /* A start date? */
+  /* Orig: if( strlen( appl_data_ref -> start_date ) > 0 ) {
+     ok = xtmFoFetchDate( appl_data_ref -> start_date,
+     False, NULL, &start_date ); */
+  /* I'm absolutely not sure about this.... */
   if( strlen( appl_data_ref -> start_date ) > 0 ) {
-    ok = xtmFoFetchDate( appl_data_ref -> start_date,
-                         False, NULL, &start_date );
+    ok = xtmFoFetchDate( NULL, appl_data_ref -> calW,
+                         XTM_FO_START_DATE, False, &start_date );
     if( ! ok )
       start_date = 0;
   }
