@@ -40,6 +40,8 @@ static char SCCSID[] = "@(#) Module: xtmNotify.c, Version: 1.1, Date: 95/02/18 1
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -49,6 +51,7 @@ static char SCCSID[] = "@(#) Module: xtmNotify.c, Version: 1.1, Date: 95/02/18 1
 
 #include <Xm/Xm.h>
 #include <Xm/ScrolledW.h>
+#include <Xm/Text.h>
 
 #include "System.h"
 #include "LstLinked.h"
@@ -66,7 +69,7 @@ static char SCCSID[] = "@(#) Module: xtmNotify.c, Version: 1.1, Date: 95/02/18 1
 #include "xitError.h"
 #include "xitStickyMsg.h"
 #include "xitTools.h"
-
+#include "xtmTools.h"
 
 /*----------------------------------------------------------------------------
 --  Macro definitions
@@ -1110,7 +1113,7 @@ static void
                appl_data_ref -> db_check[ index ].name );
 
       fprintf( file_ref, "%d ", 
-               appl_data_ref -> db_check[ index ].last_check );
+               (int)(appl_data_ref -> db_check[ index ].last_check) );
 
       TimFormatIsoDate( TimLocalTime( appl_data_ref -> 
                                       db_check[ index ].last_check ),
@@ -1130,7 +1133,7 @@ static void
 
       fprintf( file_ref, "%-20.20s ", old_db_check[ index ].name );
 
-      fprintf( file_ref, "%d ", old_db_check[ index ].last_check );
+      fprintf( file_ref, "%d ", (int)(old_db_check[ index ].last_check) );
 
       TimFormatIsoDate( TimLocalTime( old_db_check[ index ].last_check ), 
                         buffer, sizeof( buffer ) );
