@@ -39,6 +39,7 @@ static char SCCSID[] = "@(#) Module: xtmRestore.c, Version: 1.1, Date: 95/02/18
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 
@@ -136,6 +137,7 @@ static Boolean
 --  Functions
 ----------------------------------------------------------------------------*/
 
+int
 main( int argc, char *argv[] )
 {
 
