@@ -534,7 +534,7 @@ static void
   /* Code. */
 
   /* Get the name of the "parent" widget. */
-  wname = XtName( al );
+  wname = XtName( (Widget)al );
 
   name_buffer = XtMalloc( strlen( wname ) + 4 );
 
@@ -1204,7 +1204,6 @@ static Boolean
   Arg                   local_args[ 4 ];
   Cardinal              n;
   XmUbArrowLabelWidget  newW;
-  Boolean               redisplay = False;
   Boolean               visual_changed = False;
   XmString              xm;
 
