@@ -478,7 +478,7 @@ static void
   /* Code. */
 
   /* Get the name of the "parent" widget. */
-  wname = XtName( tsl );
+  wname = XtName( (Widget)tsl );
 
   name_buffer = XtMalloc( strlen( wname ) + 4 );
 
@@ -1199,8 +1199,6 @@ static Boolean
   Arg                   local_args[ 2 ];
   Cardinal              n;
   XmUbTimeSliderWidget  newW;
-  char                  *newstr;
-  Boolean               redisplay = False;
   Boolean               visual_changed = False;
 
   /* Code. */
@@ -1481,10 +1479,8 @@ time_t
   XmUbTimeSliderGetTime( Widget  widget )
 {
   /* Variables. */
-  Arg           args[ 1 ];
   int           hour = 0;
   int           minute = 0;
-  Cardinal      n;
   TIM_TIME_REF  time;
   Widget        tmp_widget;
 
