@@ -243,7 +243,7 @@ Widget
   if( rec -> display_text )
     XtManageChild( rec -> field );
 
-  SysFree( merge_args );
+  XtFree( (char*)merge_args );
 
 
   /* Create the menubar and menu cascades. */
