@@ -56,6 +56,8 @@ static char SCCSID[] = "@(#) Module: xitInfo.c, Version: 1.1, Date: 95/02/18 15:
 #include <Xm/RowColumn.h>
 #include <Xm/ScrolledW.h>
 #include <Xm/Separator.h>
+#include <Xm/Text.h>
+#include <Xm/ScrollBar.h>
 
 #include "xitRwPixB.h"
 
@@ -815,10 +817,6 @@ static void
   LST_STATUS         lst_status;
   XIT_IF_TAG_INFO    tag_info;
 
-  static XIT_PUSH_STRUCT button_data[] = {
-    { "", "", "", True, NULL },
-  };
-
 
   /* Code. */
 
@@ -1574,14 +1572,10 @@ static void
   char             buffer[ 500 ];
   char             *char_ref;
   char             *text;
-  Arg              args[ 3 ];
-  Cardinal         n;
   Cursor           wait_cursor;
   Display          *display;
   Window           window;
   Widget           mainW;
-  Widget           scrollHBarW;
-  Widget           scrollVBarW;
   Widget           tempW;
   LST_DESC_TYPE    tag_list;
   XIT_IF_STATUS    status;
@@ -2057,8 +2051,7 @@ static LST_DESC_TYPE
     else {
       char*  file_name = SysExpandFilename( book.file );
       strcpy( book.file, file_name );
-      XtFree( file_name );
-      
+      SysFree( file_name );
       lst_status = LstLinkInsertLast( book_list, &book );
     }
     
