@@ -37,10 +37,12 @@ static char SCCSID[] = "@(#) Module: xitInfoSrch.c, Version: 1.1, Date: 95/02/18
 
 #include <limits.h>
 #include <stdio.h>
+#include <ctype.h>
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
 #include <X11/cursorfont.h>
+#include <Xm/ToggleB.h>
 
 #include <Xm/Xm.h>
 #include <Xm/Frame.h>
@@ -241,7 +243,6 @@ void
 
   /* Variables. */
   Widget          mainW;
-  Widget          tempW;
   SEARCH_REC_REF  search_ref;
 
 
