@@ -45,6 +45,12 @@ static char SCCSID[] = "@(#) Module: xitParSet.c, Version: 1.1, Date: 95/02/18 1
 #include <Xm/RowColumn.h>
 #include <Xm/Scale.h>
 #include <Xm/ToggleBG.h>
+#include <Xm/ToggleB.h>
+#include <Xm/Text.h>
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <ctype.h>
 
 #include "System.h"
 #include "TimDate.h"
@@ -301,7 +307,7 @@ Widget
   };
 
   static XIT_PUSH_STRUCT button_def[] = {
-    "HiddenPb", "", "", True, NULL,
+    { "HiddenPb", "", "", True, NULL },
   };
 
   static XIT_ACTION_AREA_ITEM  action_buttons[] = {
@@ -949,7 +955,6 @@ void
 
   /* Variables. */
   int              index;
-  char             *char_ref;
   size_t           size;
   Arg              args[ 5 ];
   Cardinal         n;
@@ -1766,6 +1771,8 @@ static void
 
           XtManageChild( tempW );
           break;
+        default:  /* clause added RXTN 040597 without having a clue about correctness */
+	  break;
       }
 
       for( index = 0; index < tag_count; index++ )
