@@ -42,6 +42,7 @@ static char SCCSID[] = "@(#) Module: xitRwPixB.c, Version: 1.1, Date: 95/02/18 1
 #include <X11/StringDefs.h>
 
 #include <Xm/XmP.h>
+#include <xitTools.h>
 
 #if XmVersion > 1001
 #  include <Xm/PrimitiveP.h>
@@ -875,6 +876,13 @@ static void
   DrawButton( Widget   widget,
               Boolean  draw_as_armed )
 {
+#if XmVERSION > 1
+  /* these Motif 1.1 calls are obsoleted in Motif 2.0 */
+  /* they aren't declared by any Motif 2.0 header file */
+  /* 040597 RXTN */
+  extern void _XmHighlightBorder( Widget );
+  extern void _XmUnhighlightBorder( Widget );
+#endif
 
   /* Variables. */
   GC                    clear_gc;
@@ -975,6 +983,7 @@ static void
     bottom_gc = cb -> primitive.bottom_shadow_GC;
   }
 
+  /* _XmDrawShadow is superseded in Motif 2.0 */
   _XmDrawShadow( XtDisplay( widget ), XtWindow( widget ),
                  top_gc, bottom_gc,
                  cb -> primitive.shadow_thickness,
