@@ -59,6 +59,7 @@ static char SCCSID[] = "@(#) Module: xmubCustUtil.c, Version: 1.1, Date: 95/02/1
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <ctype.h>
 
 #include <xmubCustUtil.h>
 
@@ -720,7 +721,6 @@ static Bool
   char*                       keyword;
   int                         length;
   char*                       start_ptr;
-  char*                       tmp_string;
   int                         tok_index;
   char*                       tok_start;
   
@@ -1448,7 +1448,6 @@ xmubResListClasses( xmubResourceMappingInfoRef  info,
 
   Bool             bok;
   char**           class_table;
-  char*            filename;
   int              index;
   ListClassesInfo  listinfo;
   
